︠485d8f7c-e9c4-42ba-8856-48d026569a77︠
%auto
# This cell automatically evaluates on startup -- or run it manually if it didn't evaluate.
# Here, it initializes the Jupyter kernel with the specified name and sets it as the default mode for this worksheet.
jupyter_kernel = jupyter("python3")
%default_mode jupyter_kernel
︡d10799b7-d812-4c20-8422-487970124a3b︡{"done":true}
︠f64ce01d-582c-4042-8afe-e6cf86bad0e1︠
%sage
sage_server.MAX_HTML_SIZE = 1000000
jupyter_kernel.smc_image_scaling = 0.5
︡2b3d3a75-46c5-495e-a38b-40b7fdc15d45︡
︠baefde40-8f85-43c5-9e45-197282a9e13bi︠
%md
# Studying the 2024 April 8 Solar Eclipse with Astropy

## Goals

- Learn about the 2024 Eclipse.

- Model it with Astropy.

- Check our work against the USNO.

## References

- Demo notebook by H. Snyder for the 2017-08-21 Solar Eclipse
  - https://share.cocalc.com/share/6240aa60ea491184867f4691b042d7d108326478/Public/Eclipse.sagews?viewer=share
  - used geopy and pyephem
  - did not use astropy

- Adrian Price-Whelan, Visualizing the 2017 eclipse with Astropy, 2017-08-20
  - http://adrian.pw/blog/astropy-eclipse/

- US Naval Observatory 2024 April 08 Eclipse information / Calculate local circumstances
  - https://aa.usno.navy.mil/data/docs/Eclipse2024.php

## Extra Sources

- Juna Kollmeier, TED Talk
  - The most detailed map of galaxies, black holes and stars ever made
  - https://www.ted.com/talks/juna_kollmeier_the_most_detailed_map_of_galaxies_black_holes_and_stars_ever_made

- Astropy 3.2 (2019-06-10)
  - What's new:
  - http://docs.astropy.org/en/stable/whatsnew/3.2.html

<img src="ats_0212024.gif" width="30%">
︡87b8d6c1-25f9-4937-9b00-828b50d56228︡{"done":true,"md":"# Studying the 2024 April 8 Solar Eclipse with Astropy\n\n## Goals\n\n- Learn about the 2024 Eclipse.\n\n- Model it with Astropy.\n\n- Check our work against the USNO.\n\n## References\n\n- Demo notebook by H. Snyder for the 2017-08-21 Solar Eclipse\n  - https://share.cocalc.com/share/6240aa60ea491184867f4691b042d7d108326478/Public/Eclipse.sagews?viewer=share\n  - used geopy and pyephem\n  - did not use astropy\n\n- Adrian Price-Whelan, Visualizing the 2017 eclipse with Astropy, 2017-08-20\n  - http://adrian.pw/blog/astropy-eclipse/\n\n- US Naval Observatory 2024 April 08 Eclipse information / Calculate local circumstances\n  - https://aa.usno.navy.mil/data/docs/Eclipse2024.php\n\n## Extra Sources\n\n- Juna Kollmeier, TED Talk\n  - The most detailed map of galaxies, black holes and stars ever made\n  - https://www.ted.com/talks/juna_kollmeier_the_most_detailed_map_of_galaxies_black_holes_and_stars_ever_made\n\n- Astropy 3.2 (2019-06-10)\n  - What's new:\n  - http://docs.astropy.org/en/stable/whatsnew/3.2.html\n\n<img src=\"ats_0212024.gif\" width=\"30%\">"}
︠b833e649-bf1d-4e92-b5f5-386b362b4461i︠
%md
## Step 1. Get basic info from USNO.

(Ok, this is cheating.)

<img src="usno-2024.png" width="70%">
︡6b16c271-c882-49cd-9c75-935e4d68fdf8︡{"done":true,"md":"## Step 1. Get basic info from USNO.\n\n(Ok, this is cheating.)\n\n<img src=\"usno-2024.png\" width=\"70%\">"}
︠65627985-2c82-43ec-9558-b6f7d63eafe4i︠
%md
## Step 2. Follow the steps of Adrian Price-Whelan's 2017 notebook.

This will give us animations and the setup for basic stats.

Add geopy so it knows about the Palatine Library.
︡a07722f0-877d-4635-b49a-2c074d5f68f7︡{"done":true,"md":"## Step 2. Follow the steps of Adrian Price-Whelan's 2017 notebook.\n\nThis will give us animations and the setup for basic stats.\n\nAdd geopy so it knows about the Palatine Library."}
︠88cf7070-0360-4465-855c-169938672dbbs︠
from datetime import datetime

import astropy.coordinates as coord
from astropy.time import Time
import astropy.units as u
import numpy as np
import pytz
from IPython.display import HTML

import matplotlib.pyplot as plt
from matplotlib.dates import HourLocator, MinuteLocator, DateFormatter
import matplotlib.animation as animation
import matplotlib as mpl

import math
︡737480cc-f714-4d81-abf4-1206e5c819da︡{"done":true}
︠6ff553fd-a5ed-40ed-910b-56ef7e7b25d8s︠
mpl.rcParams['figure.figsize'] = (8,6)
mpl.rcParams['axes.titlesize'] = 26
mpl.rcParams['axes.labelsize'] = 22
mpl.rcParams['xtick.labelsize'] = 18
mpl.rcParams['ytick.labelsize'] = 18
︡c4392255-05fc-4b1c-831e-eb4a386c0de7︡{"done":true}
︠009b2a1c-f8f8-45a1-a29c-1562e7a46dfbs︠
# Set timezone here:
mpl.rcParams['timezone'] = 'US/Central'

# Enter address here:
address = 'Palatine Public Library, Palatine, IL'
︡17ebbce0-139d-4610-828a-f9af5566f5d0︡{"done":true}
︠f3c2215f-0b09-4e72-97c9-4def9edf5c9ci︠
%md
### Choose a range of 1024 equally-spaced times that span the eclipse

17:00 UTC to 21:00 UTC
︡ed25e1f0-dd6a-4eea-99ca-e36feb22041b︡{"done":true,"md":"### Choose a range of 1024 equally-spaced times that span the eclipse\n\n17:00 UTC to 21:00 UTC"}
︠0659b885-7d6b-48a9-a1ba-5db443aae49bs︠
tz = pytz.timezone(mpl.rcParams['timezone'])
times = (Time(datetime(2024, 4, 8, 17, 0, 0).astimezone(pytz.UTC))
         + np.linspace(0, 4, 1024) * u.hour)
dt = times.to_datetime(tz)
︡00cc0cb4-c066-4abe-9f62-59430c6330be︡{"stderr":"WARNING: ErfaWarning: ERFA function \"dtf2d\" yielded 1 of \"dubious year (Note 6)\" [astropy._erfa.core]\nWARNING: ErfaWarning: ERFA function \"utctai\" yielded 1 of \"dubious year (Note 3)\" [astropy._erfa.core]\nWARNING: ErfaWarning: ERFA function \"taiutc\" yielded 1024 of \"dubious year (Note 4)\" [astropy._erfa.core]\nWARNING: ErfaWarning: ERFA function \"d2dtf\" yielded 1024 of \"dubious year (Note 5)\" [astropy._erfa.core]\n"}︡{"done":true}
︠eb57ebb1-811d-41a5-87bf-68045d79501fs︠
# geopy gets street address and county for the library as well as long/lat. Cool.
import geopy
from geopy.geocoders import Nominatim
geolocator = Nominatim(user_agent="chi-eclipse")
location = geolocator.geocode("Palatine Public Library, Palatine, IL, US")
print(location.address)
print(f'lon: {location.longitude}, lat: {location.latitude}')
︡e8602051-05cf-4530-aca0-28d6054ca14b︡{"stdout":"Palatine Public Library, 700, North Court, Palatine, Cook County, Illinois, 60067, USA\nlon: -88.0366723932833, lat: 42.12225845\n"}︡{"done":true}
︠b39bc680-e0b5-43aa-8567-3bb2678fe3c9s︠
location.altitude
︡0cd519c0-8c5e-4397-82b5-b5920019d6e6︡{"stdout":"0.0"}︡{"done":true}
︠f12e5c55-69da-46a1-9c9c-e9ba6a6f3f1as︠
loc = coord.EarthLocation(lon=location.longitude*u.deg, lat=location.latitude*u.deg, height=0*u.m)
︡34660c4b-29f8-411e-be50-100faedb8047︡{"done":true}
︠884639f2-f6b4-4c74-b661-bff400a978fbs︠
# use the astropy ephemeris to get coordinates of moon and sun
# for the range of times
moon = coord.get_moon(times)
sun = coord.get_sun(times)
︡42f88a74-b96b-456a-b6dc-91c73b0a0dfa︡{"stderr":"WARNING: ErfaWarning: ERFA function \"utctai\" yielded 1024 of \"dubious year (Note 3)\" [astropy._erfa.core]\nWARNING: ErfaWarning: ERFA function \"taiutc\" yielded 1024 of \"dubious year (Note 4)\" [astropy._erfa.core]\n"}︡{"done":true}
︠75269c21-b7a0-40c9-95fa-67522d51bc8fs︠
# adjust for our observation point
alt_az = coord.AltAz(obstime=times, location=loc)
moon_aa = moon.transform_to(alt_az)
sun_aa = sun.transform_to(alt_az)
︡ca02deb6-7602-4db1-9c76-36b536507bcb︡{"stderr":"WARNING: Tried to get polar motions for times after IERS data is valid. Defaulting to polar motion from the 50-yr mean for those. This may affect precision at the 10s of arcsec level [astropy.coordinates.builtin_frames.utils]\nWARNING: ErfaWarning: ERFA function \"utcut1\" yielded 1024 of \"dubious year (Note 3)\" [astropy._erfa.core]\nWARNING: ErfaWarning: ERFA function \"apio13\" yielded 1024 of \"dubious year (Note 2)\" [astropy._erfa.core]\nWARNING: ErfaWarning: ERFA function \"utctai\" yielded 1024 of \"dubious year (Note 3)\" [astropy._erfa.core]\nWARNING: ErfaWarning: ERFA function \"taiutc\" yielded 1024 of \"dubious year (Note 4)\" [astropy._erfa.core]\n"}︡{"done":true}
︠62bbd2d7-76ce-4273-830b-33ae1fe33e5bs︠
# plot the course through the sky of moon and sun
# they are very similar!
plt.plot(moon_aa.az, moon_aa.alt, marker='None', linestyle='-', label='moon')
plt.plot(sun_aa.az, sun_aa.alt, marker='None', linestyle='-', label='sun')
plt.xlabel('Azimuth [deg]')
plt.ylabel('Altitude [deg]')
plt.legend();
︡2dfbd7b9-e812-455d-bfd0-329825cb49fa︡{"file":{"filename":"/tmp/tmpK2y499.png","show":false,"text":null,"uuid":"891a3fab-a13e-4bed-9277-14527a4d05c5"},"once":false}︡{"html":"<img src=\"/blobs//tmp/tmpK2y499.png?uuid=891a3fab-a13e-4bed-9277-14527a4d05c5\" smc-image-scaling=\"0.500000000000000\" />"}︡{"done":true}
︠fa2beabd-bfca-408f-8746-f35c768f0414s︠
# the key to eclipse calculation is the separation of the two bodies in the sky
sun_moon_sep = moon_aa.separation(sun_aa)
︡53d303a6-b929-4c78-96eb-588dd1984b96︡{"stderr":"WARNING: Tried to get polar motions for times after IERS data is valid. Defaulting to polar motion from the 50-yr mean for those. This may affect precision at the 10s of arcsec level [astropy.coordinates.builtin_frames.utils]\nWARNING: ErfaWarning: ERFA function \"apio13\" yielded 1024 of \"dubious year (Note 2)\" [astropy._erfa.core]\n"}︡{"done":true}
︠0d040eda-cc80-4b4c-ba18-6378ad778f44s︠
# plot the angular separation as a function of time
fig, ax = plt.subplots(1, 1, figsize=(10, 6))

ax.plot(dt, sun_moon_sep.to(u.arcmin), marker='None')

offset = 350
ax.xaxis_date(tz=tz)
ax.set_xlim(dt[sun_moon_sep.argmin() - offset],
            dt[sun_moon_sep.argmin() + offset])

ax.xaxis.set_major_locator(HourLocator())
ax.xaxis.set_major_formatter(DateFormatter('%H:%M'))
ax.xaxis.set_minor_locator(MinuteLocator(byminute=np.arange(15, 60, 15)))
ax.xaxis.set_minor_formatter(DateFormatter(':%M'))

ax.set_ylim(0, 30)

ax.set_xlabel('Local time [{0:%Z}]'.format(dt[0]))
ax.set_ylabel('Sun–Moon separation [arcmin]');
︡01f00745-e6cc-4a58-8522-fdbf79524e16︡{"file":{"filename":"/tmp/tmpaQGBpS.png","show":false,"text":null,"uuid":"5b78f5cd-6f5d-4fe1-850f-9ee025d416bf"},"once":false}︡{"html":"<img src=\"/blobs//tmp/tmpaQGBpS.png?uuid=5b78f5cd-6f5d-4fe1-850f-9ee025d416bf\" smc-image-scaling=\"0.500000000000000\" />"}︡{"done":true}
︠0a7cd034-bedc-4d09-a39f-92eba99df1cbs︠
# Animate the eclipse for the time range
# centered on the sun
# approximate shapes of sun and moon by 1/2-degree ellipses

i0 = sun_moon_sep.argmin() - 128
i1 = sun_moon_sep.argmin() + 128

fig, ax = plt.subplots(1, 1, figsize=(6, 6))

x = np.arange(0, 2*np.pi, 0.01)

moon_pa = mpl.patches.Ellipse((0,0), width=0.5, height=0.5,
                              color='#666666', zorder=10)
sun_pa = mpl.patches.Ellipse((0,0), width=0.5, height=0.5,
                             color='orange', zorder=1)
ax.add_patch(moon_pa)
ax.add_patch(sun_pa)

ax.set_xlabel('Azimuth [deg]')
ax.set_ylabel('Altitude [deg]')

#ax.set_aspect(1.6)

fig.tight_layout()

def animate(i):
    moon_pa.center = [moon_aa.az[i].degree, moon_aa.alt[i].degree]
    sun_pa.center = [sun_aa.az[i].degree, sun_aa.alt[i].degree]

    moon_pa.height = 0.5 * np.cos(moon_aa.alt[i])
    sun_pa.height = 0.5 * np.cos(sun_aa.alt[i])

    az_lim = (sun_aa.az[i].to(u.degree).value - 2,
              sun_aa.az[i].to(u.degree).value + 2)
    alt_lim = (sun_aa.alt[i].to(u.degree).value - 2,
               sun_aa.alt[i].to(u.degree).value + 2)

    ax.set_xlim(az_lim)
    ax.set_ylim(alt_lim)

    return moon_pa, sun_pa

def init():
    return animate(i0)

ani = animation.FuncAnimation(fig, animate, np.arange(i0, i1),
                              init_func=init, interval=25, blit=True, repeat=False)
︡36006d00-25dd-424d-aab2-3c448186261f︡{"file":{"filename":"/tmp/tmp3mWlgz.png","show":false,"text":null,"uuid":"c7739bd7-9287-495d-b27e-8aaec0662028"},"once":false}︡{"html":"<img src=\"/blobs//tmp/tmp3mWlgz.png?uuid=c7739bd7-9287-495d-b27e-8aaec0662028\" smc-image-scaling=\"0.500000000000000\" />"}︡{"done":true}
︠b9e2ae70-c21c-4adb-a27f-07c31f551e67s︠
HTML(ani.to_html5_video())
︡7c5d52a2-b5c0-4d76-ae90-3232802a7e1d︡{"html":"<video width=\"432\" height=\"432\" controls autoplay>\n  <source type=\"video/mp4\" src=\"data:video/mp4;base64,AAAAHGZ0eXBNNFYgAAACAGlzb21pc28yYXZjMQAAAAhmcmVlAAEOqG1kYXQAAAKuBgX//6rcRem9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\nYXZmNTcuODMuMTAw\n\">\n  Your browser does not support the video tag.\n</video>"}︡{"done":true}
︠43bfe4eb-2a50-47d2-a79b-2e3add63b4f4s︠
# Animation with frame fixed in the sky

i0 = sun_moon_sep.argmin() - 128
i1 = sun_moon_sep.argmin() + 128

fig2, ax = plt.subplots(1, 1, figsize=(12, 4.8))

x = np.arange(0, 2*np.pi, 0.01)

moon_pa = mpl.patches.Ellipse((0,0), width=0.5, height=0.5,
                              color='#666666', zorder=10)
sun_pa = mpl.patches.Ellipse((0,0), width=0.5, height=0.5,
                             color='#fec44f', zorder=1)
ax.add_patch(moon_pa)
ax.add_patch(sun_pa)

ax.set_xlabel('Azimuth [deg]')
ax.set_ylabel('Altitude [deg]')

ax.set_xlim(180, 255)
ax.set_ylim(35, 65)

fig2.tight_layout()

def animate2(i):
    moon_pa.center = [moon_aa.az[i].degree, moon_aa.alt[i].degree]
    sun_pa.center = [sun_aa.az[i].degree, sun_aa.alt[i].degree]

    moon_pa.height = 0.5 * np.cos(moon_aa.alt[i])
    sun_pa.height = 0.5 * np.cos(sun_aa.alt[i])

    return moon_pa, sun_pa

def init2():
    return animate2(i0)

ani2 = animation.FuncAnimation(fig2, animate2, np.arange(i0, i1),
                               init_func=init2, interval=25, blit=True)

ani2
︡839edb3b-043d-420a-a568-314b255c58d1︡{"stdout":"<matplotlib.animation.FuncAnimation at 0x7f926888ec50>"}︡{"file":{"filename":"/tmp/tmpCNb5sA.png","show":false,"text":null,"uuid":"acb75e41-841e-432e-9b86-c109169bea08"},"once":false}︡{"html":"<img src=\"/blobs//tmp/tmpCNb5sA.png?uuid=acb75e41-841e-432e-9b86-c109169bea08\" smc-image-scaling=\"0.500000000000000\" />"}︡{"done":true}
︠115ed589-0335-4a30-8f0e-7ba3fa13a82es︠
HTML(ani2.to_html5_video())
︡ad71cb29-8c60-4ab9-b9a0-70eb79d4750d︡{"html":"<video width=\"864\" height=\"344\" controls autoplay loop>\n  <source type=\"video/mp4\" src=\"data:video/mp4;base64,AAAAHGZ0eXBNNFYgAAACAGlzb21pc28yYXZjMQAAAAhmcmVlAABZRG1kYXQAAAKuBgX//6rcRem9\n5tlIt5Ys2CDZI+7veDI2NCAtIGNvcmUgMTUyIHIyODU0IGU5YTU5MDMgLSBILjI2NC9NUEVHLTQg\nQVZDIGNvZGVjIC0gQ29weWxlZnQgMjAwMy0yMDE3IC0gaHR0cDovL3d3dy52aWRlb2xhbi5vcmcv\neDI2NC5odG1sIC0gb3B0aW9uczogY2FiYWM9MSByZWY9MyBkZWJsb2NrPTE6MDowIGFuYWx5c2U9\nMHgzOjB4MTEzIG1lPWhleCBzdWJtZT03IHBzeT0xIHBzeV9yZD0xLjAwOjAuMDAgbWl4ZWRfcmVm\nPTEgbWVfcmFuZ2U9MTYgY2hyb21hX21lPTEgdHJlbGxpcz0xIDh4OGRjdD0xIGNxbT0wIGRlYWR6\nb25lPTIxLDExIGZhc3RfcHNraXA9MSBjaHJvbWFfcXBfb2Zmc2V0PS0yIHRocmVhZHM9NiBsb29r\nYWhlYWRfdGhyZWFkcz0xIHNsaWNlZF90aHJlYWRzPTAgbnI9MCBkZWNpbWF0ZT0xIGludGVybGFj\nZWQ9MCBibHVyYXlfY29tcGF0PTAgY29uc3RyYWluZWRfaW50cmE9MCBiZnJhbWVzPTMgYl9weXJh\nbWlkPTIgYl9hZGFwdD0xIGJfYmlhcz0wIGRpcmVjdD0xIHdlaWdodGI9MSBvcGVuX2dvcD0wIHdl\naWdodHA9MiBrZXlpbnQ9MjUwIGtleWludF9taW49MjUgc2NlbmVjdXQ9NDAgaW50cmFfcmVmcmVz\naD0wIHJjX2xvb2thaGVhZD00MCByYz1jcmYgbWJ0cmVlPTEgY3JmPTIzLjAgcWNvbXA9MC42MCBx\ncG1pbj0wIHFwbWF4PTY5IHFwc3RlcD00IGlwX3JhdGlvPTEuNDAgYXE9MToxLjAwAIAAABg+ZYiE\nADP//vbsvgU1/Z/QZX4PcvSTANns6rF19/Wkv6Yp0UOaXQImAGMMxVdJLC3f9Xxo3InR9XwABmUT\nvyMJ2sXfh4PJSv9Zh3r59Jf1dxKPck8VZec8AAADAAADAAAJLRQ4Tuo5ac9YRvzGoxU9SL8MLZyX\nGwbQOxd02uMDToWBWgJHK/6obnKRyz8CEckQDJTCuUioTboE6ivlzbPVe7NvnYpVRX07m55keDoF\nBZean9N1nWRsY5yKKPx4hFyA/d9jDRWLVD7thRTXMd6E/6QafIlcal22rOJdjv2y5g8w1/3zr/ab\nq5UUtbQCLwah4ocGEPur0T9/7Pm0CF906AlZdct+pe0XvmN85sHVQAAAAwAAAwAAZ/uu2LICABx+\nYdQIprspP7UwMbDlsrUM6AAAKXgrwgFRpbhT0cdkNM0tMl/KOgMlPSmGOrdhlgOUN6z8DKODMPUg\nTd6KMeqbBkXJz/AI0NR32J4CPtUPZp+OMdRctgn3il8ZOGilZ0HagZ5/3KLNuADpthm4rJmR+LY/\nATgpE11PUIFsxCSNlWVR2s1QfGTZ0G5gC0xwAAADA08HzFe+UggUtYcUv3WAc4xL/DUfiZo0X78i\nSVttTSu2MrhDY8KjsqToFWUEU9Gvoq0qL4sFxFHwwWPjYGnPIBaxCFcAA8se/hZs6d2ydDjDFFN5\nZW02r4ELWqH9HgT+6D038qGiTHhnoqfxzhg2H93s+sazC+sG+J4AAGKNeAEtbNYPPQADnKD5/1gI\nahfzdhzhepDoj770uk3cnYy/ohQDUIagwRwE7iRod+UtEbPu8tI28qNMonONGTRp6fvQ0J30j3dz\nv2Tr7TCEb1tqN7OSBZcJZYDW7hPPI/m+pZdMCr2rWP7KqzEXEFPxT81e5lgmkHULzlkr0OF4VWF6\nqMilHn8YZkLdO5WVBMYSkbCqW8AAEXY69RLcMFVoiosBoSu1qsIK+Ts12r7qmezNDkSF0Ba8JnAf\nfBTcA8ULWAHkCP4cJhBZqwFJ950cXY7aFx98P1yh97yfvAv0vpsx/V760Jhai8xda4YBm59QFwWB\nyorGE+pRLtP6B9gWDPLLz6wCMpUdD0upAECz4DMl1UOgRwui7yyevcUwCDMD5EsGhDx1F6aXNMsF\n+l77gRz8VsWxMTo6n+lq1W3GaX0uU/oS069HWCldMJ4tgfuoSnrl9jkdXabCMcRgMmja4kO+MlAp\nY0opzp0Ddnd3AAz9AnwUujCCrz83th4NRdzHMVBNnnWatLzQd8haPAquI0TQh8wF/oAE9L97jVFc\nTi2pqVSu9iYi7IKh6XBu3z2jb8AAAA1uHqaZWuxrZllRMm3T47uMRmpGkw+zx4HIzmroWQJglr+Y\nDz1L2bHH7aYcWRnxDE7u2vFXoEsdHfvWAJUTMvppwZOxaXE6OGHSA13+dnZB/HJqauQKLibPUoZp\nDNQ16LsVy9BAQ6ubklM9d9usS0jG2CyCKOxK0gFdrsxX8Dy+1l/3+WG8lHKfVfGtgP3wR4TEnPzT\njEFUX7WT73p5n5Pf5T9Uv1PQzSohbvPYaKxTh9hbVJrVbNTjeJg3T8AcYaqc5VPlC2sa77Qv3vi3\nP5sVoVoNIB+GF2BKQo7ELHUwAChadAatvxuJS7olkMwt7aupIYN/yP4hSYQ6GJf0cOqslqve479B\nfnF6cK5WnAej4GLNwogSurV/GJYmvKkKb1xidlFpd/lxSkY2poqnCxy/wr4KxLLD4r/AoQcqxU7c\na3QRTgDdAtysEA2Jsq1LTCIzyfANSZ6Xg+tbyNzK0+ka8cYKopM9weUOvY94BlfdN3bGe5UaaF8Z\nB+6Qr+qARIsB1NKzFCCmRUPQ7hxPFpyYh0aktPPvPWwpbbQNibBu7jjc/PNzs/YgN37ty2FuntHT\nM1gIjnHgBnAULlUBZydMhIgfCKHENlYPbp2BWnONjY5Drq7FJ2nChcRvEMCuMUc73Jb1oXM6UYlf\n0EfH4WzrpMvO3+FIUbJts6C06D5y66zEaZl25ECd2uxyNVxA5xvPlzohohZh/xme+XL3UmWgUp+4\n322BFDNCiYXCjAEdQgopOnZ7dZL7HX5zg4/eoFmqpG8pkiOjyZnDuYr4ZZ1QXkflcQUItI3XQ40z\nZrrqk03KwtoitIUJXy1XGBl4U51MI3xOfpMmB9djQnC/8aBeeAFAAAASenQnZDpeOZsymroZ1ApH\nyX1GwkdZBBH/xfUnk8C90sGo2uH9ktM9URclLRFgf81ts0dtjnx1HbF87z2F3mXLR43XLYTNyObx\nknNHgjGzxYfVM/+zsiDMQ9rRPjqbKXpv6xAM0P+tK3qaGUZj6hfPfb+SI94i99nGAAADAAADABI5\nK9diSKs7d2uPf+6I/FzNgMHBZsLtqDtXhhuAluCZ89ZO0RPFPJER0+qO1r5j8yQSIJkmK1rBFdHf\nsJ0GQoZRmomGeWEwNPAhSY7Gd5jD3KQC+QlP/7PMny4mgH6//e04hLDGh4Rk8nHUR9vtKltYP4W0\nGrKD1jQaW21qCIBLGHx0SLK5oLtLyoZkTT9bKRAcdD/Y+rmQt2CdPGfNMpdGBF+Hejv71wAAB2Bs\npb4Uef0FMXgTJHWLer/1rqO4Y0Z2Ln3WX6xvN0P0VxubE0mX9W7iLEywVZuGQ4oB6XSbIusP1cG6\npU96tMc9Z2CeOS6Oeh7XbSv2P9cDulZ1vYLC03vjJnKM8MmkSPCvwUAd/K5nVaO7mMAuxz0hCknH\nbwfXeyLmBWZmrOFG8m7RY4xXaZ7Y9YgAcqhGIaIMBwVY5FNTyymzqx0uLpFJTQMudbFZds1nG3dX\ni5lPBrvPryJrozz/y5SGi6oEKIiFnNS2mKBc53BnBfQwg9md9BoMBZOPnTClPvINabBU+0HlNqqL\nDoQMRAhtmy9ajyGOptGVaCDbKrYbINByFM4dIHqJkvjsDrlBzxFyRl5/mBczbYAAMnbTFP/ZMYoT\nMfIE7LKgYavRREGAuZT0ZuGezHF5q0V8QWGqDaQShBI5+T1VNBGwIr8+huhqO5vkuGhtp0lW8YDT\nlv1BCJT2cRkSMZ3aN3Jky1MTauHJizlupt1RArIfYTEVif45JVA6KCqxI+TP/3aSC6pg7AJMksB1\nExMlAAADATHPBbNv7Smg5TSUKl7C8itso4TiAqUmNQtCAZfzphaVycv3v1kUnjmMOW5aG59ikl74\nJDSoT4zbK0QtVVnWrQe0j0U9K791/gC5wuJMNsG//DTg7z134lrlfQI2HJkA8awk+08qm0TgKn1K\n4x1oCA7nL1ExRa20zM+qMWgZjRKcl5khgpSxEC6YAAC13jIyLzsEL+ysKsErpojyl/cbs7mMygXg\nn8YpVCxxAIgap3Yr1yZUlyExtwH1SFeDR+PTM4RwYRemQs9hkVHlgTl4y3Ct4qlon801g8DRMrjH\nToLydQN2ouoTXGYOt9I9T/QW9UZ96VnXlrJozBPvY4kudKvoPROKxg9i+QthH+CncAAF+ZTQABBz\nkwdCO3+T6+XLN7/l4V3uHIrH9YMxHLWvfqz7pp70tFlzcDKh2sDgmV8Md+Qjf1hQA7Vj3odRdAZl\n9CEAzm9UKWYeDfdHqo9J6PdQJ53u6NTMIj8athn3Lf5/9R4X4j/FcBO6SRqrM4kEew0AoBs8zzBY\nYmHik88K02UDFo9L7yKxuV8/a5HaY48vfB/qxxeaXI+XpPe5g1LVnciSMJcAgSwyF1cHhxLTDyKw\nIe5YVr2JZGlFaDXlm1FkH6LZWJv4lnvWrrjxs1IV/6fEE//VdYcG/RsP4CnQ58QfPGMgF/z0LVRL\nJRTgeQ72kdBKAqcWMq5p2tGwWoZ+Wowx3xAlfSwsv+VNPxQGRazqHhyDDAJkev3W8wId7KuOZnzm\nKSQ/ccUqHDlgw6cjXNeQBOl+v7cAlHWNBIaOq8S20tUojy9JGL1YpmHhu8ltrzmefuqL1k+Tbwxk\nfr1g6R8A9h61Ah+lNgoD703T2Fk7uxetvVfQKmeO/Hq1MmDJm0NH5kBB2Z1lsy00LJ9ZTaXwG81B\nkbM2DoOd/tVdhB7YpbP6+ZoNz4f+T4P86fhaHJ6XEcTwbhzqOC1FWQQ35GuqyCYcY9fG1xjOVyuj\nlBNMFkKNs7b7Z11kfCBeUATaeutM2AQqStz1pWNDgmR98mZkaFIrlwQijffFmZHCcUN6L4rTCRNn\ni89nndyjap/p4JpIc/g4B2RpIkp5AJ+EL7vorSPTTFo5MOzYaoDnvZeaEUwbChUx3quE5sP1U5q/\nXkAYgVRyfbsxez1lmRtxEvfUqQAKS5263eYZ1JBc6XZiMeaIM2G/U7XoS7VYwJ0Ir8yF08Szg09V\njhhB003uFaZfA7F2i/tiRClP0r6U9+ULo/dFsB5SZXh4asiDvFAwyVuwNTovtig1VlvDKgZjpc2P\nL+MEomfAqos126Dz3x6KCPzpOEQx9/Kde2YMXCYzjMOF/pIhVHgYlOpUuDINWeuizx/WXmywGiKn\neer15+ze5f74QgWa/Z/PQi7aV6qD7PKchx4/Ct4uTyRKOcUlbtrmqEfLy1pJGImaN/piIA4kMD1/\nu55fmWRctxluHP5/N7/47E5nF4HPUfSGTtauWL8f0gZpr3+RgaYU1lJBTCKVvLDp3HgTtzhRMMSw\nuGeikaB7fJBzHrULkp0QDKeV0nKHlsYT5XaDC1s9uuwK4nJ6obc2Vw37GPbPYSZFLDyXo3ps0WP4\nJCP4CSc5HoPB3eu6UMxEM3kq8uR/iBptsZoEqmVMIfal+zpzpuTTOuLoPZAohTBkUD4Q89Gt/qMp\niAHUPqKzV0s4eJ6j5nvWy06t779zfEhSNaRwvI8r/uIZwsmEyGvXt32hXCBy/C17TTx2/5Qn/O48\nZ6AVk3vCtwCvuaTT5SS1b/Pep2NVfr7voAQqMGshVlOBDwpY28j22mTggSHm9TneeyjiceoryIk6\na1ZKhav0oAo9BQAKYC7dQnM4f3Ll+aRw+9fd4hmNAHUOIdaB7cnwV5MdUtKG7Op0945dV0a8ot7B\nw6TUXeYw+7fb5FU3laeWPj/9YZqRaEWhoyP/rIL1SXc5kU0bWxP5/ixeoX39wNWUqn1ahfXJCp3P\neOf3ic1REjG84Snkn96ehs5BVO3XAbbwfzkxO2MeLew/MWWwvYdZcWkhaiEg6lZ05hMWgVoS2IUU\n1AEyKE2jdeGCaMbS+ms8QuQqB/XkFBRRRzQu55uWt+72T5j/JpYy+RBbdVAuNEAHiXeB5yAHLJsK\nQ5eXqjyh5+uQwjMCXDyexk7P4A12IYqFRckN9wi2ln+opDPxaRXTmxxMpd6PX1M5rWbmn5IZfdOu\nPXlqkNXCTx3z3ufjkdHXwwoghDZChVT1mv+MLmYHVS3a/CjqGk8b9ni6EE57Q2moMisf4ASWEq+G\nT40hY6L9I9w/rficYkw5I4kEsSBO7q54buvVCmSBxQc/to3pnTjFeudF6L7B1X50YZk4LrN4r/jv\nmZr4I7xxj32K1JUt1QZO2t65uWhbbwUIPtx+GQ9fQae3IqBRHnx4lEcfkHZR6389KQBc6Td0hC1R\n5iIU7biVV+lL8nxFHOgodOxcBrlKe7knMJO2OJmx3F5hL9U0FE74z76uGhh1sQ2RtcM32s3DfGFt\nwJSZyDu4kYCapEpNPSdHBgDXh4TuuBjGdGXn0SJ0XjtSbMthcbUef5FeZ/L3BUWfvoe1E3pToM+4\n5peEnJON69ArMyfBehIfeHpTTqy3pjHZ3jVbXtqEH4njOwHDGv81iwZ3EWESWYkxPXfXPpBq2b3c\nnT++qmrcmZHPagol+4Ed/jz2cqdMFJXnDVOMTT1ow5C0lcrupNwYtZs6/IRXs4xVUBmuwVHsjBK4\nxYxT2Gmg1YlT23IKjW5kohEBIKwWqPSMtcIB+E4y5pZiHAAhwiC/B6HmmCNczg45Hgl2GZAWknQK\nz1YB59QS7WYZZpN+O2TqAyGHdmtxwDzGPu9nfH1huGrKZgrVWDinhIDPWatVQkNxTmKEtOsbUvn7\nrwUG+KdL1nWNWlfD5RJkN6jDWYm32ytbAYhQHybVbhfwwC6yolTKYAxEG6h1tst4gEc+Vt+WjgfF\nGI1aB/3RE3NBNmsgdQTcVWy1X1nYSKPLlKc5We6agDUWiRNSIi09YYSqKpBTl3eYaYyh9b3QdAD0\nZ2XXkw2ztXWZnDPyFKlHDU0xskXJtMPWbaA1ouMz3Iq+I/NZ+ZhKfeua0bieht0d1+uX89EeGtN0\nm5HtPT2wwST9Ma37Tc9R+sJzRrC7O5N7wzoVkiQkfJ205E5C7Wc/plMK30WRaswF+ZtH8k73iLrC\nQT4CllB/c4xY/P3EETk8rznB6DlxB1gbYbKSDz/17hJyNwFqpnokMRqA2tlEoOWtlskj9f5M1xa7\nleIeSut/BUK+nByybJbZFXXsL49soAGgzaf2e51ZUdnrddUiOdQWMbyHB8HajWS6DM0w+hpurYQe\nn4w+uPysef/+55JfTUg11kJuXNtVGShnGBby3dmo8IQQoidMNvZlpof7Feyd6qHUCTM73Uj76FIl\nDYEfTX/DdizeDOI5LFJAJj6Q8Aerhl4qSFVnLg7xjHvNYRJwH9CEm77je5U0SJC6VYy1JsWKsbUs\nD//tQqt5yJYy+1IPfEySK4Fikp1dZDU9zSfRrKYwHYAsZ1hPk7mJIovtM6X/InhbpS+1XQBVAHg7\nx6YJ7g9l3oHNJGAjmCuSktpECUuXDwzdr7y9oXcRbZwsuuoEm17FuXtNXQWhOIX8n0w5QL7GtKl/\nHf9ZJiKKff4DSetczs+J56GoTZQqkR1vAhbCAAKj3VUAZ2/wvA6l40bYtVR4xVxSH4YL3xv/oby/\nKqDiYyvJxlFncLJ9VwDSFjeAwHduRlN0LXu3YW1EEzVl5rTQeq1GakLXcUaaSS0V1vBHCMQ2k0Kc\n0j/XnomL0EZ/krhIJ4VnOdnBq1+2MyD31T505npfdxy6jLnslHrDregMQdmosdOOIRL9lUCZGxDD\nMF/MIjQMxX6mvdM4Vh/ThXoS2TrcmtEI7Z/6+9j3aOJxg8+xwQ/c5Xdl7G4/7nDuB4Os6oNkPjFv\nG4pGqZB1V2ZEST/usH1LedyzqSOyB5+kstnIjvCPeM9Kw2/WEtElNA/xHfTiafEm2mBRWC/myIW2\nFXoDY+IK071CSQUlbaDAc/+d+hBG5p5o0c/mvLgkSfWU93zP4JstaxyTW0IeHiq3zozQYeTDILqN\nP1Aimn7GvudbF8x7uFHvvuI+dEZNLHju6MefPB54sL//M7rXOqlsTb5RseWNe4D7HPiF6i4keCBF\nycOdMgS/7CXFwNliois87Fug/PCpRCHYEmnkww7eEIZp0X0zOUJ12H3hw9XylcFVCrEAJ4C/QqCm\nmoqdLNaUJPaoILTiFcCYX33n7vH9WfqxLt7l2kOB66JsaqeCUAFLF0ZX/fPvyeVlQX775s0MNk45\nZU8G93EgZguwFi3H473sfCdjNja3hpG0TBArUz5EFeZkOGTHbs5pM13BsQOEmGws3p2hkovtZTMD\nJ5lmEQJ2kIf8nUv0rEImsGkdJLjmCV32cd8O66Nycv/dSd/9wxNAKWtrc+8d3a2HFpIWIc64txDT\n8DZ/muffj5s2rL/xOTLmRHjXlGS+dRi8FBJe1abQnxUZ7JnUx5OYozJQIh0z59RO7mdwpacBlPyI\nPW20MwhHXbtaRMZX10Rx0wS/7qjDpa+fnhtd57a8LV157zusADDLcipjBbAN7MxjrHfE2mkfHEWO\n+lPyCwFbzVTiYgfXQqvuqGI9DkIeag7TiFdOAtzeyUDYUFp+R0ok0/1eUzro/XdYGVeBthPlO3lv\n5hTjjURlF0K4wl3qdxnE0t0CtXG1u6g9eh/7JcEuzzF9rQuiaCSNzqBq97bUB7R3+SMrp+2OhqHL\ntrabtoB53FvbrNQGJhRPP72VYLKyv4lXnFgAFVRamnCbFT9hF0OGztU++RWma4e6E4RuOiPGHPE/\nlaOzRoifsmIdE0xFa6p8XYM6LFYGTRsXS68kGCqN8FGRJ5G8B/GXQFGzTo7RX/+DXgJQl8umFPCL\nQ7W6iaPKjZZrkJmmWeeG+cQ4a2hG9o9t6XfyziRoXjDBT/fdPMcylKodK5GJMQ8d09/PMg0XdmoD\n46f4igJAvJJp7UvC2F45zPDKpzbxRvRL3O9eWUuwtZrmm3T7syyc/LTFt9V+7ns/qIlfrABg/OnM\ngDxN72GIBpujxpLsC5kqCNmIBXpbVTj1Mk5W7uoqHtAxPoAA3jQs4n2q0DiAsoEAAAEjQZokbEM/\n/p4QABxEcIATXoiwHrUlxyTcnyqUpW547J+uFGLm2ieW00ExyjYI73meaGvQ5xVPkkvjGdx5VN8R\nmujVc43+760K77p+MmFO/HQu+ZVHUyiw12U//w0/QyMflcjRtPmPOBmcgVteHLTL7zqBm7cy/CXP\n65v+v+BSK2UH0imf234d4XkkKJNYtE0wtQ5d3ARAeiMH3aDytjwVddCuqoCveMnIovyyAqAvDtCn\nqR+2B7yWdZ6AmHcD24M89kJ//BsNGRLchBK3B7YZ7KeZpCJCGmGA6LgsOOxIoHBMV8gxss1ElECz\n/hJm4awzJzKTbfpTrwF6oEd57nCL6p0zbxLEsIMbfIVViKmpdxHHNLdjinJBWlcFWm04bOAerLxI\nAAAAOUGeQniE/wAB1jd8clyiOuGk8jfiOgMoygcMoB1IzvG28RdOgeU/EljiBgODYzIssdhsYN27\nKsxP9QAAACoBnmF0Qj8AAjq/Sc0f/vLSgy2Ev1b+Wb/wYbBTkVqGAffLAn51LwK4zUAAAAAbAZ5j\nakI/AABkpjSdGceaAB5l9fUor7Ykdg6FAAAAW0GaaEmoQWiZTAhn//6eEAAHEV83gAjIMbiP+ll5\ntJ/ftNto8izuXxZ80SAcVM/qm8DbI7PSgfs2up0JIHW5+Q1mIPnZDMwlB7xN9vCMDlVEGE5DSNVe\nfjAiLFEAAAAoQZ6GRREsJ/8AAdu91uho1e3ceGzCFEAJx+XoDdHI3WK9FH0An9vyYQAAAB0BnqV0\nQj8AAGR+a2+4DQwmgAeWAkhh8zHvkBzZ3wAAABoBnqdqQj8AAjvJyTk9jO2/n+RAALFTjJU5QAAA\nADBBmqxJqEFsmUwIZ//+nhAABuaVkT+l3HIMgFrJlZxlmQBHmfWeTM17tGkBAAADAakAAAAhQZ7K\nRRUsJ/8AAdsI3Dy8elBdzAjEABkVuc0r5heUtSYpAAAAGQGe6XRCPwACOr9JLSYz9wc9XQAEtFZk\nGxIAAAAYAZ7rakI/AABiJjrdV7EkLQAB/GVAlXdAAAAAKUGa8EmoQWyZTAhn//6eEAAATbpvPE5A\nVXnoAFLRzcbeeWC/owAAAwJfAAAAIUGfDkUVLCf/AABR/N9WIdkv2Hz1gADqTRYxQ/Vo1luGcQAA\nABkBny10Qj8AAGH+eKuGGO/aI8AA3LwzUhUhAAAAFAGfL2pCPwAAYiYzwQ/JAAAX6LLwAAAAJ0Gb\nNEmoQWyZTAhn//6eEAAAS3KnJLRAqNgAjyq97s/jeWLAAAD0gAAAAB9Bn1JFFSwn/wAAUfzc/ZDH\nJ3XAACEdsLIPIFhXmdq1AAAAFQGfcXRCPwAAYf5uNTVIABuYq2PPtAAAABgBn3NqQj8AAGImM8EM\ndAAAAwGcSrOw0MAAAAAwQZt4SahBbJlMCGf//p4QAAEu+LFmtVd7POACL+zTbL1yjVJubwlUL8M3\n8VIAAA35AAAAIEGflkUVLCf/AABR2U3TZ1/mfDdAADv/urPtuaN2awDgAAAAFgGftXRCPwAAYf5u\nNRAiaAAO0NyHC60AAAAVAZ+3akI/AAAYiNQ3VytgAACc9IyBAAAAKkGbvEmoQWyZTAhn//6eEAAA\nS0PcVaih3sh0yaFR2t5W5i12R2ZAdWyVgAAAAB5Bn9pFFSwn/wAAFHq55RV0WAAIST5pSrXfKBjG\n6cEAAAAWAZ/5dEI/AAAYijC4pvYAAW64rvKtwAAAABQBn/tqQj8AABiAa7UF7AAAE56gkQAAAB9B\nm+BJqEFsmUwIZ//+nhAAAEu6bzxOQE+m06AAANWBAAAAHUGeHkUVLCf/AAAUdlJh/bAAAW2RnZKa\nd8DlMjXQAAAAFwGePXRCPwAAGHUkA30n0AADZbuV9OuAAAAAEgGeP2pCPwAAF+BshCAAAu+GcwAA\nABxBmiRJqEFsmUwIZ//+nhAAAElUoNcRMiAAADZgAAAAHEGeQkUVLCf/AAAT6rnvyQADtMoKEFwQ\nJzdTJtUAAAASAZ5hdEI/AAAX6jEaoAACcm9yAAAAEgGeY2pCPwAAF+BshCAAAu+GcwAAACpBmmhJ\nqEFsmUwIZ//+nhAAAEk4YZLicF4wTIAG6vRd9zINGmntOgAADakAAAAgQZ6GRRUsJ/8AAE6lZ/MT\nYaUuoAAXbYvocQgmja5FHoEAAAAUAZ6ldEI/AAAX2kW3+vQAAGpE5kEAAAAYAZ6nakI/AABfpjM3\np70MJoAA8rg7UV5gAAAAKkGarEmoQWyZTAhn//6eEAAASXByuIy8AERiRYLsJNacj7tP8+jAAACg\ngAAAACFBnspFFSwn/wAAT7zdQ0ISBPHrejAAG5Ya2PWwQMQZpNsAAAAZAZ7pdEI/AABffmnSo202\noeZoAA8tx00mSgAAABcBnutqQj8AAF+mM7+3iyaAAPMsNNkiYAAAAChBmvBJqEFsmUwIZ//+nhAA\nAEm6b0ChlElJ84AEOtxWc4W63adAAAG1AAAAIUGfDkUVLCf/AABPvNz1gO4Wr1UcAAIiafsuRO7J\nTufPQQAAABcBny10Qj8AAF9+bB8gQHkAABU4BED46QAAABUBny9qQj8AAF+mLgOmMdFAAAJD2JYA\nAAAnQZs0SahBbJlMCGf//p4QAABHUOriRCAA3tRNnjBKKtGiJ2qAAAG9AAAAIEGfUkUVLCf/AABP\nvNwIOwRX+crDAALmpg3uA6oiBbFnAAAAFwGfcXRCPwAAX35sUwkPYUAAVPOsOAigAAAAGAGfc2pC\nPwAAX6Y0s3q3+5mAAYhQ5qwygAAAACpBm3hJqEFsmUwIZ//+nhAAAEdQ6uI6yQA3YIYiZLmsi9Le\nrWiKOAAAIOEAAAAiQZ+WRRUsJ/8AAE+83baElKDQcV3g82gAhIBEdpEVI5PmkAAAABcBn7V0Qj8A\nAF9+bFedtzhYABFLm414UQAAABkBn7dqQj8AAF+mNLN6t/sVuGiACSBg96JRAAAAJ0GbvEmoQWyZ\nTAhn//6eEAAAR1Dq5G3iEo0AbDhGDNhO2206AAAN+AAAACNBn9pFFSwn/wAAT7zdtozbFzcWALCQ\nVoAISFuJXZHWd0zx0QAAABkBn/l0Qj8AAF9+bFR+N2uS+JDQAGbCjcunAAAAGgGf+2pCPwAAX6Y0\ntJAGO2pEmb2AA87sav69AAAANkGb4EmoQWyZTAhn//6eEAAAR79KaDGiJWsG05BQaSvhOMpBSbRx\nueCDHwryc9EIXI88AABDwQAAACJBnh5FFSwn/wAAT7zdtrrfOWcEilKvwAKhITkYOJiCCzagAAAA\nGgGePXRCPwAAX35sVIAMXqKuamgAM15m5OdAAAAAGAGeP2pCPwAAX6Y0s7seLCOBwAPRfxt+2wAA\nACVBmiRJqEFsmUwIZ//+nhAAAEVDzNScADjOqRNevIGfgRAAABxwAAAAIUGeQkUVLCf/AABPvN23\ncslz/MWW6NABr+hHRvRUZQZ7RwAAABkBnmF0Qj8AAF9+bGJd8J8OyE/gAqdpgP7uAAAAGAGeY2pC\nPwAAX6Y0ujBq3uUR4AKpCY281QAAAClBmmhJqEFsmUwIZ//+nhAAAEVQ6uIy8AEWody2iUZ+poyz\nVFTAAACkgQAAACBBnoZFFSwn/wAAT7zdt3LqWoZeo0AGu6Dx5LlsAg8TEQAAABgBnqV0Qj8AAF9+\nbGJnjxa5Y8AFTWYV1xUAAAAXAZ6nakI/AABfpjS6Mv5OHAAKpCX/ztQAAAA3QZqsSahBbJlMCGf/\n/p4QAABFUOriCv67QBBSQ3e+3+rAt1cTwoBhpdxXNr8sK4fOd+OxSOE54AAAACRBnspFFSwn/wAA\nT7zdt3LJfUUE5LXcb4QgATU0Gaw8lBm5pyEAAAAYAZ7pdEI/AABffmxiZ48MlPwAA0m7QNXKAAAA\nGwGe62pCPwAAX6Y0ujMACqbJZOdogAYZ+EgIqAAAADRBmvBJqEFsmUwIZ//+nhAAAEW6bzrNVQ8A\nH6cYAWVLViNnT0qvuXlpfkHSQksGbFSAAA8JAAAAJkGfDkUVLCf/AABPvN23cupZlULwo5GuQICI\nAE0xIzHSWCnwED5BAAAAGgGfLXRCPwAAX35sYmeIlg8fQ+2gAOb/u96bAAAAGwGfL2pCPwAAX6Y0\nujL+H4yf6WyCgAqDHhMXSAAAAB1BmzRJqEFsmUwIZ//+nhAAAENQ6a4S6wd/oAABiwAAACJBn1JF\nFSwn/wAAT7zdt3CUQYfGFIQlcAF2+k5mi0zAC4+rAAAAGQGfcXRCPwAAX35sYiBjChnP7IAEs/A2\noEoAAAAZAZ9zakI/AABfpjS6EHyO7apvABXYTG7RaAAAACtBm3hJqEFsmUwIZ//+nhAAAENkKj4A\nx1hAPCIG4AJ3onKwi+Za4YAAAIeBAAAAIkGflkUVLCf/AABPvN23cGpah4n34gBAAuwoOlCctkLP\njxwAAAAZAZ+1dEI/AABffmxiJ4lQFqQIAEsr9hq5QQAAABkBn7dqQj8AAF+mNLoQZ5U5OfABXZF+\n8EqBAAAAKEGbvEmoQWyZTAhn//6eEAAAQ0PcELyAG6ziZ5BthJoKQnMpUgAAPWAAAAAjQZ/aRRUs\nJ/8AAE+83bdwalo9GBNq6teIAOJKaQjWTsZjPNsAAAAbAZ/5dEI/AABffmxiIG1+kSMfJM4AAc66\nkOGOAAAAGwGf+2pCPwAAX6Y0uhL4zk0UiNiSAAHZGIC/uwAAACpBm+BJqEFsmUwIZ//+nhAAAEO+\nKzOY+ppXQZOZxv2AGc7WWlNCfPAAAR8AAAAnQZ4eRRUsJ/8AAE+83bdvQNM2MdxOUa735xlEAHD2\nEN5HL98oI9aAAAAAGgGePXRCPwAAX35sYiBJOB8jmkUAFYFgPniQAAAAHAGeP2pCPwAAX6Y0uhL4\nvlFoVRpHtAAdrqEIr6EAAAAvQZokSahBbJlMCGf//p4QAABBvYfoQwRUNIskjAib/14OmudQabl3\nmFf4hSAABEwAAAAmQZ5CRRUsJ/8AAE+83bduJgGis4ONR6+WbXQAfAvuUHofco7GkYEAAAAaAZ5h\ndEI/AABffmxh57EwFa+QGuAA7I8AW68AAAAYAZ5jakI/AABfpjS29KcPCaYgAmtkjbzVAAAAHkGa\naEmoQWyZTAhn//6eEAAAQU4JrntnTClP4AABFwAAACJBnoZFFSwn/wAAT7zdt233T2bzbXd90QAS\nXWFaQxM3cQTFAAAAGQGepXRCPwAAX35sW+jhdlPa9oADXnkn9ysAAAAYAZ6nakI/AABfpjS29KdW\n9LtAAa7XN9RtAAAAMEGarEmoQWyZTAhn//6eEAAAEFQ6a4Mn7mTAr/bzmKfJNVDg/eFtyXkIR/VX\ntPbBwAAAACRBnspFFSwn/wAAT7zdt2uZLyXmu67trK+KAEM5o0gPc9+UrQkAAAAZAZ7pdEI/AABf\nfmxb6OF2U9r2gANeeSf3KgAAABkBnutqQj8AAF+mNLb0p1by8fVAASeULFQFAAAAHUGa8EmoQWyZ\nTAhn//6eEAAAEFQ6azLVzPRgAAFlAAAAIkGfDkUVLCf/AABPvN23IYenp13czBcqADnvIRsSDake\nX58AAAAaAZ8tdEI/AABffmxb6OO/rvriqAAk706L/CEAAAAaAZ8vakI/AABfpjS29KcPBsBufAAz\nhkhIRSAAAAApQZs0SahBbJlMCGf//p4QAAAQbpvO+Wdst/4Af+PhZTdqmEzadAAAeEAAAAAmQZ9S\nRRUsJ/8AAE+83bdqaWuOw1YL6uzfRp3IAT7HRNAhiAhCMNEAAAAcAZ9xdEI/AABffmxhoUStco43\nJQTC5ABrt4pBwwAAAB0Bn3NqQj8AAF+mNLnTSpR9rqbNrcdmACb9XvvZYAAAABxBm3hJqEFsmUwI\nZ//+nhAAAA/ZyztImRAAAHpBAAAAJkGflkUVLCf/AABPvN23a6l3ktjKWJk5W8hxgAbKn1JIv3cy\nlRcwAAAAGgGftXRCPwAAX35sYaFErY0YD5EAFyu/Jp7hAAAAGgGft2pCPwAAX6Y0udNKlIhpyIiA\nC57aM0kRAAAAKEGbvEmoQWyZTAhn//6eEAAAD9UCdVdeP4vgAjiRGn9B8zFziwAAEfAAAAAkQZ/a\nRRUsJ/8AAE+83bdrqXeS20bXd2bTuABc0D30HuIiXYMhAAAAGQGf+XRCPwAAX35sYaFErYn/1VAA\n1xjjy6IAAAAcAZ/7akI/AABfpjS500qUhNLEfYsmoABzm6i1LQAAAChBm+BJqEFsmUwIZ//+nhAA\nAA/qUQeLzb2piNAA5xtw+t6fZmbAAANTAAAAJ0GeHkUVLCf/AABPvN23a6l3kto5UhbgzSPSrcAC\n55tkNFQPhAzUkAAAABwBnj10Qj8AAF9+bGGhRK2NGATYBLQAHOJLSxvAAAAAHgGeP2pCPwAAX6Y0\nudNKlIbo253ooSqAAOgc7fK0gQAAACxBmiRJqEFsmUwIZ//+nhAAAA/vU+BrPdBneQxZXwEUDFx/\nhGJwD59GAAAW0AAAACRBnkJFFSwn/wAAT7zdt2upd5LcbjU5xo3gBFOdNIDmjkbr54EAAAAcAZ5h\ndEI/AABffmxhoUStigJVdF20ABziS0sbwAAAABwBnmNqQj8AAF+mNLnTSpSIacLHa6AAOelQViHB\nAAAAH0GaaEmoQWyZTAhn//6eEAAAD+8JzxOKbcp6MAAAtoEAAAAjQZ6GRRUsJ/8AAE+83bdrqXeS\n28qq+HbtwALnU0AwzQmBR6MAAAAbAZ6ldEI/AABffmxhoUStiFQd67QAHNcKKxtBAAAAGwGep2pC\nPwAAX6Y0udNKlIyvVqLQADtPDsSkwAAAACFBmqxJqEFsmUwIZ//+nhAAAA9/l8svIAZmTNJ1iwAA\nEnAAAAAmQZ7KRRUsJ/8AAE+83bdrqXeS4G1Uldr5HjrQAWEMZkB6IleCjIEAAAAaAZ7pdEI/AABf\nfmxhoUStm0vhFAALTgQw3qAAAAAbAZ7rakI/AABfpjS500qUjKHstjOQAEHJG32BAAAAP0Ga8Emo\nQWyZTAhn//6eEAAAD5DG47FzgyACHXQQbPALAOcqX5Qm2BFAgy2gwly5hhqb0m3Apx0hU0USBOA3\noQAAACtBnw5FFSwn/wAAT7zdt2upd5LggnWgkgBusoi1C4wA97iQa3moTPWeWNmBAAAAHQGfLXRC\nPwAAX35sYaFErZtLgj28mQAGLmAobl5NAAAAIAGfL2pCPwAAX6Y0udNKlIyYCUy91uUAa5diWMU1\n5j9wAAAAKkGbNEmoQWyZTAhn//6eEAAAD3+XykJkZNAFJwN8sdzvidRe4Aw4Eqxl4AAAAC1Bn1JF\nFSwn/wAAT7zdt2upd5Lggnf2iABEpres2XwEEAe8KSagX5v1AJxfdIEAAAAfAZ9xdEI/AABffmxh\noUStmjoKwp/gAmm8Q9huoUu5QgAAAB8Bn3NqQj8AAF+mNLnTSpSMob2iXOcoAJauEcwJHiJAAAAA\nJ0GbeEmoQWyZTAhn//6eEAAAD5cJkgG8KUYANIjkJxrGFsUcAABLwQAAACNBn5ZFFSwn/wAAT7zd\nt2upd5LgdTzFqfExYwALFWBNPi+uFAAAABgBn7V0Qj8AAF9+bGGhRK2bS2P0ZygAAZUAAAAYAZ+3\nakI/AABfpjS500qUjKaBjqxgAAOnAAAAG0GbvEmoQWyZTAhn//6eEAAADyeXylMiAAAP8AAAACJB\nn9pFFSwn/wAAT7zdt2upd5LgNZHd64mdcAXwcGGDvHhRAAAAGAGf+XRCPwAAX35sYaFErZpXn7rs\ngAAIuAAAABgBn/tqQj8AAF+mNLnTSpSMX26IDEAACLkAAAArQZvgSahBbJlMCGf//p4QAAAPL+QZ\n7ZSOAAD/TYHr3NJO9rI7IBYsAABLwQAAACJBnh5FFSwn/wAAT7zdt2upd5LgNZHiAlgGABaawN49\nrOxgAAAAGQGePXRCPwAAX35sYaFErZo3f2L8pwAAHHAAAAAeAZ4/akI/AABfpjS500qUjGr0v0AJ\nPfEyXpBwAAELAAAAO0GaJEmoQWyZTAhn//6eEAAADyeXxDFABEvgzbKfbydWUT7iRwTKrWYzXnc5\nJ73c05Y6WxzX5gs9eA44AAAAJkGeQkUVLCf/AABPvN23a6l3kuAt9hJLHYhibjAa/FNNQN1FMKcR\nAAAAGQGeYXRCPwAAX35sYaFErZqAsn3psYAAGfAAAAAdAZ5jakI/AABfpjS500qUjF98429k3XYL\ngIwuAW0AAAAxQZpoSahBbJlMCGf//p4QAAAPKcr8yHLtT89gAi9j/T85jYSzGnys6OypASHz0S7W\nwQAAACdBnoZFFSwn/wAAT7zdt2upd5LgM2En0nBe6kuC6APiIe8QJHnRpfEAAAAcAZ6ldEI/AABf\nfmxhoUStmn/2CTOwDgBF6UDRgQAAAB4BnqdqQj8AAF+mNLnTSpSMaskues7Bis3AWs3A+4AAAAAl\nQZqsSahBbJlMCGf//p4QAAAPPwnOsvlUZAbe3KuVsA9XbfrtbAAAACRBnspFFSwn/wAAT7zdt2up\nd5LgOJABORON/MBrkY7qB0Cbg3EAAAAdAZ7pdEI/AABffmxhoUStmjvJO+1hj88AOw8A44AAAAAZ\nAZ7rakI/AABfpjS500qUjCnQt9jEIAABgQAAAClBmvBJqEFsmUwIZ//+nhAAAA7Pl8s+QAGfhCso\ne3esH36spoj0AADegQAAACNBnw5FFSwn/wAAT7zdt2upd5LgBRPvQkjqCa4AwyRI4RiTrQAAABkB\nny10Qj8AAF9+bGGhRK2ZnEZ1rLwAAEfBAAAAGQGfL2pCPwAAX6Y0udNKlIwp0LfadfAAAf4AAABK\nQZs0SahBbJlMCGf//p4QAAAO0pw83V5AESu/b/6SMHuBnJovz29lzz3WzRhPh34cQV+jEWHelo6c\nbfFkcKhSAldMxdejWelAdMAAAAAuQZ9SRRUsJ/8AAE+83bdrqXeS4AUUBKcAVfGwaE29ZC0AqjTo\nA94Cm7w8ZMYcUQAAABwBn3F0Qj8AAF9+bGGhRK2ZfXdr5QoAGIXJ7oLKAAAAIQGfc2pCPwAAX6Y0\nudNKlIwgAD1INqjsFM/AWtj8mKgNGAAAADRBm3hJqEFsmUwIZ//+nhAAAA7nsd+yXzIFUANT1hv4\nOBcZDWG+Aug4V1k6c4DPkv6AKig9AAAAJUGflkUVLCf/AABPvN23a6l3kuAB/fo0b2YHgC2REt1A\n1swj7GAAAAAeAZ+1dEI/AABffmxhoUStmYolI09vD0va1ABrYwHrAAAAGgGft2pCPwAAX6Y0udNK\nlIwkAmjwgCSEgIuBAAAANUGbvEmoQWyZTAhn//6eEAAADo8J0kS8WyEq+oOMIAgB83HuEPQvXc1D\nUfAKN1+QDd8Wry70AAAAJ0Gf2kUVLCf/AABPvN23a6l3kt+9n+92AfdLhiYAH7watwDW6rLFQQAA\nABwBn/l0Qj8AAF9+bGGhRK2Yre4TGt+UAASRIBlQAAAAGgGf+2pCPwAAX6Y0udNKlIlcnYU3NAIw\nuAf5AAAAJkGb4EmoQWyZTAhn//6eEAAAAwOd5T99+UALVICqYFUAi3z2aImZAAAAJEGeHkUVLCf/\nAABPvN23a6l3kt/Gx6KVrZdgAM1ueEYOagMWaAAAABkBnj10Qj8AAF9+bGGhRK2QJ/no4ALTgAg4\nAAAAGgGeP2pCPwAAX6Y0udNKlIlcXkXHNAIuSAk5AAAAK0GaJEmoQWyZTAhn//6eEAAAAwOd5fEx\nqwAQwv66DjZutISn5wBxvg1oiZgAAAAnQZ5CRRUsJ/8AAE+83bdrqXeS38bHofPSZN/OQV+AQccw\ndwa23PNFAAAAGgGeYXRCPwAAX35sYaFErZAsBQVSYAtM4DMgAAAAHAGeY2pCPwAAX6Y0udNKlIvj\n4o2d5NPAAfkoCPkAAABIQZpoSahBbJlMCGf//p4QAAAOjwnSRLxbWE592WwAIj0NlSRzmJsRtvwF\n9XtLcInbVQF3WKKGM48LWNRyUZu9ClVpeCk8E7SNAAAAJ0GehkUVLCf/AABPvN23a6l3kt/J7Ih2\niFkOMpgHCLXfJGDbirDxgQAAABwBnqV0Qj8AAF9+bGGhRK2Yre3uchfN6ACB5ATdAAAAHQGep2pC\nPwAAX6Y0udNKlIlaO+EAK2vmA/VXAA/wAAAAM0GarEmoQWyZTAhn//6eEAAAAwOhsmoduN7DQAOg\nbzeJ1plqfjxNStNOjAGd+DRuPgTKwAAAACVBnspFFSwn/wAAT7zdt2upd5Lde7Lv3Wb94MBdkd2S\nQ4PyVe/FAAAAHAGe6XRCPwAAX35sYaFErZAn/jA4b6AR9EcAh4AAAAAYAZ7rakI/AABfpjS500qU\niRKASd0f6dSAAAAALkGa8EmoQWyZTAhn//6eEAAAAwOjwnOsvm98MARL5d9SPQAz92nQEZ8FoYfX\nnzEAAAAnQZ8ORRUsJ/8AAE+83bdrqXeS3Xv99XWCuDwuKAP2OWbSHBpsk30JAAAAHAGfLXRCPwAA\nX35sYaFErZAnB7inbeALmsuAPCEAAAAcAZ8vakI/AABfpjS500qUiVp/w06SYAuWEABgQAAAACVB\nmzRJqEFsmUwIZ//+nhAAAAMDipl24ItUaqiwCo/F9mcml8KAAAAAJEGfUkUVLCf/AABPvN23a6l3\nkt1708nDFhKAP43tueoYdKcjmQAAABsBn3F0Qj8AAF9+bGGhRK2QJoi46dAI+lSAYEAAAAAZAZ9z\nakI/AABfpjS500qUiVpeQpuaAACNgAAAADRBm3hJqEFsmUwIZ//+nhAAAAMDiKcD9+oAAcJOg0jp\nN8zZ7VOiu/+7n5SQfHTwvdp0AAI3AAAAIkGflkUVLCf/AABPvN23a6l3kt17ygzcX/e4Ap5cMLf4\nxHAAAAAYAZ+1dEI/AABffmxhoUStkCaIuOnQAARtAAAAGQGft2pCPwAAX6Y0udNKlIlaXkW/UHwA\nAf8AAAAoQZu8SahBbJlMCGf//p4QAAADA4flPPRMjJoAztUYDL4mP8KFIAAPmAAAAC5Bn9pFFSwn\n/wAAT7zdt2upd5Lde8nHk36s86O4BeJ/AkrjwWlK4Ai4gFpU/MJxAAAAHQGf+XRCPwAAX35sYaFE\nrZAmiLjH7zGz5ALXj66YAAAAHgGf+2pCPwAAX6Y0udNKlIlaXQAbvubOnSSA/7XpuQAAAC5Bm+BJ\nqEFsmUwIZ//+nhAAAAMDiHKvlXmOf6QBOKSF5x0Jl3wY6/4rNzNgAAd1AAAAJUGeHkUVLCf/AABP\nvN23a6l3kt17yZ8OfR9rqxlQMQ5Cjcf5uIAAAAAaAZ49dEI/AABffmxhoUStkCaIsznevAAAf4AA\nAAAdAZ4/akI/AABfpjS500qUiVpcvAsRtJ0eUAAAekEAAAAsQZokSahBbJlMCGf//p4QAAADA43C\nc6ynpXXoAgQhG2eDvILtI7o2bAAA7oAAAAAkQZ5CRRUsJ/8AAE+83bdrqXeS3XvJav6zb8IPfMBF\nxAYW/xkTAAAAGwGeYXRCPwAAX35sYaFErZAmgLrD1Krl2AAE3AAAABoBnmNqQj8AAF+mNLnTSpSJ\nWmI7+2gIAAAVsQAAAB1BmmhJqEFsmUwIZ//+nhAAAAMDc2rZ60nzgAAdMQAAACZBnoZFFSwn/wAA\nT7zdt2upd5Lde8mwIYjY95yepbgNH6DW38MlwQAAABsBnqV0Qj8AAF9+bGGhRK2QJplF+sCFmkAA\nBwUAAAAaAZ6nakI/AABfpjS500qUiVpiO/toCAAAFbAAAAA9QZqsSahBbJlMCGf//p4QAAADA3K5\nfRy2AHDf9DlNp1jwKmqZqo5vEYmYZ7Cn5BppfcrvJnEVjJIR4wACBgAAACVBnspFFSwn/wAAT7zd\nt2upd5Lde8sfrfXIRPMd3AaTgGkFrrexAAAAGwGe6XRCPwAAX35sYaFErZAmmW8tmiOQAAB8wAAA\nABoBnutqQj8AAF+mNLnTSpSJWmI7/NZYAAATcAAAAE9BmvBJqEFsmUwIZ//+nhAAAAMDcrl9BwCY\nYAE+su3rGxsWqwjeDAweJusdfaaSmDMMXz4NtH+kZcuIIzcin9DvBYFGgrhUcRpw3hfQGzxhAAAA\nJ0GfDkUVLCf/AABPvN23a6l3kt17yx+t9VQcNx69AJLqjz4J4OAHPQAAABwBny10Qj8AAF9+bGGh\nRK2QJpmhMu1p/NAAAOOBAAAAHgGfL2pCPwAAX6Y0udNKlIlaYi1sBKa9HkAB8CgN6AAAADJBmzRJ\nqEFsmUwIZ//+nhAAAAMDcrjjBusAk5c4UwAT+b3Ho9YhnD66/OOAT4lOoUbFgAAAAChBn1JFFSwn\n/wAAT7zdt2upd5Lde8sfs7Wp5d+nedTxlgAi9wLaHhFzAAAAHAGfcXRCPwAAX35sYaFErZAmmaEH\nXo9S6QAAHzAAAAAcAZ9zakI/AABfpjS500qUiVpiO+4/2DzpAAAOaAAAAClBm3hJqEFsmUwIX//+\njLAAAAMDfetmRkbW/Q8wDPsAQActrVt2YgADpwAAAC1Bn5ZFFSwn/wAAT7zdt2upd5Lde8sdmtx6\noIAOEPKsehDnZUuwAjOoHZKGe4gAAAAfAZ+1dEI/AABffmxhoUStkCaZcFxS3AM+VgAKzmBBwQAA\nAB8Bn7dqQj8AAF+mNLnTSpSJWmI0P7Y2lM2GQACMXoVtAAAAHEGbuUmoQWyZTAhH//3hAAADADNk\nY31zsUwAB0wAABa1ZYiCAA7//vdOvwKbRZdp76+EdH5eYAcQBkLxIvMl0CmekH5Y6tPOu5yiREPb\nFDlgQLNNhtKns7FKGXIsOCaunTrBe6UwdIj+UWS8AQ4rOsox4AAAAwAAAwAACnojwaPUctOebGd6\nSr/7R9QJ9B3wm4bzYSGELePp42yagnJVDWJXgzI3H4k65yaceuj+u5aCFrXWEInzNy4J7/dTvXF1\noeTUARG0n7jhzAQRuNGFi396yemwnC/HxmZevRBo4YGPnt8ogestYozvF5mivK4zFkYjtzhLDi/i\no/LnZ1R+Qj1e4icpzHTtnKRpqP1wkr2iQVr80/R9SchXzURU80tkAAADAAADAAADADC9qOfjifT0\n1ocooqTfZidWy63HPodbXSZYAAChORR+TRL8+OEJf3ErHuz/SbFxOeMtrR5yCaB2bUwFzggzEcW5\ngVxo7xAvYUo5hCkPzCSXDY1tL6RrKNjjUroAmdo6tuX4siqYI5BZ5rxOvt5ZI5rEzJGBhZP+lhm9\npB1qWvBMP8Maf9rpR83Mfdb+ky3tqAAAE8Smjcw+AGEGEZ4b1UKT6/nUuJW05gAv6wwmtWQWmjWv\nwna5FagT+Or8JI+Ara3pzzBaEUxbdRO/rHr1DxGRUWrUJilrkVvLKsDwzYv3ZM0Czf7yhE16/XBC\nmMNTADo48nxginKB5L2eyXlsr0AAAAMAYz5FQZ0GEge0ST1d4HeAzqviE4Z2GXt7rZdVOZqq3AfG\nSs8+bOHeWttQOd6Lu5r8YqvI7F+0XLGv2cI6Rq9c2sGYPH2hzz1bMIftMLi1kiBYLFYde7ZRbN9a\nJ1X1kgXIaZwMyaRFtxaFLeaJqJyKauDk8VSII1RuImKVKS54LKSrGYKtpMpUXdnen84e4gAAInHM\nKhQLToxz+mbiBljgXS58QBo1Sd2SicfKg2A0+0h9+ju7RGziewJtkKIsEAyZGqSt5WU9Dykj3FW6\nBdgTScbFxoqePHY64WMyd4dJ26I1mQAtVhkhsemeXYheXCVy4VhJtnBK0jt/12meyzxfHW17tCOb\npRO4qVWkZY3FN6NijJ1+tB0P02CruP38xj1ELMIHdXE0DOrScC5aA0HackA0oW7vuvoZ6J6o+uai\nO131Sljw/ltEU+GL0sm80DIPqD5rARYpLfo5yieuRevXyIjpfqK5CTVFttRG0tqlXKziOgUm7Hxn\nZXhUaEP2tXXYm39CDI+Uz6oK1JQQ11OmLkAAAAuykE9RvNszdJZRzyo1IF7Vy4jqO1Jl2ZFBVkft\nwSjQ0w+r9F45dUs1r4rU8oXcIyAUxj9io6xXdbrHH5wO1uxLDwmX9ppl+iEXhmlaYVMSsJ5Z4mTG\n+xzfMm+krGPDx929CeWAWRj2W+L86Ve3Gl83J4kMl7XAhk7OpaeX3mbsbgKa4Sa5ESDZFseAaMzH\n3NyvHACXCIBxPfNTkQxy2lFPS4AASLVhCMlPMF+X/bAqB66xyz+hnwoG3jLp8ws1EMdyIrYoQDOL\n04YiX/hRXq346zYpbDbgtt+H7aiflL32GNH6W7Gmptj8yotKLqUi528TnYj3LmzJVYAANKDL9rD1\nPUyDXW6DKQBenefkv1M/oyUp4DcU6M81pC5hkL9/67vkz14052c1ciQv9njEVzDTVDbgDtwQDJNX\nny2tGcn+6Q2iAnDh/KHiYlO8ZBUrjHtIdDwRJVsdyIwBtjIh1BY26s1LTvZWJJnuhwwRlsaAKKF8\nrXnlO96U7iohc6bCB2QfMecwdZ7sH/cIom5iQbPH96c3sQNG6Z7l4PGhByj+Wh7RPSK8QiAnxr2W\nJTu4SU27a8+4UqRoDwF3gTEIc7ktP0CWmETZzyL2u/HLJVyuJj4l174/p+OzVbCOmmlGJ3Z6nN8d\ngKGODLjFUAkORGv+kGaWJ8l6ylrbz9KWkYo0r4yKOqKhV0U2U1Jtsq6sJ3lIhT6zYWkbRJoMGf0S\n9TGlkPoP0AARt+s9BADiQ38kFZcx1nsD2BKwjQCiZ6zQIMdX29++XzHvgIWR3yYzedZUGB+3Ar5y\nk0OkNrvkyOKntpp1USKvpFCyZO/KDOjxAY0ERuQchKbdz1mbmBf+Z7ejYYEuf1wwbsd4+D8LR/OI\nG72RM5GAVRbjlCkMarv364DfFXmIDCpwAA8IxNcF6sx3PXz+p5BV/kznOQbdOzxfIDDiKoQ4dBhm\nxNkOgOxl0mftc8fPETNW/QgxTIYd00ElylopkvscCPhn8Fd/yBvc7z+6Mzr+WbubPzSnPDuJXytN\nvJ5F8nABGT2URNXC2Px91kfKYFGLJIGoH9B5Aua+7zqfZLlkBZ6b2IGCZU711xCWlLOhKASYtA69\njGw3QHv6f1xe4GaGUb2n6tdHfmXUjB4YhagdYUid/GRTpAqBSK2PdoCAMOqjgNekpS5Y8GWOSa/u\nz8EKDaATyRP50wfjVWJcS6N1ByRlztfklKAR5mcJQxfukrTBlZohhCSH//HR3a/QJnci4zV4DJdY\n3QyQx0gB8fq2e/UbATQMWakf2h+bgVNIkRhb4GixgZGwZLEkh08AxJ+ilNPcjJwtCcjZnmDGcMSz\nsQDSOBC3+nlViWz4mpdjaaikz69mL5cI5nMkB6gRNHJVFzwj3gefiLwgIrnVJAj0fcvzYjNTbHQ2\nNbOFOcr9UfMo99qrX854SpmSpcDRuunSbHw3JlhBdZvnpHLgV/p3SXEtqVkN7AgwP6g/Y9jCMpL5\nZuoqLmd93gMWkVxLzS4kqt3qSgoAAObWYm54aYk+PHqlkUNZMFFO8fGw128hVj++GnMwrY9ygw/A\n5EVjQFfK70b9Hrd6Iq5fpGODtPiRpWqMfeCGbV1sIukUr+lF2z5KhwWQcXn6r8qPIRcT2VBWinb3\nfhsrQfS7sCM/uzCzOnowRgWLoNfQx5CdAAADAeOqoWbr2rcf1flC4Ew9O+GaT/z/fv5cfKW6l06g\n/BfrJGIf+Yp9N8QQVpG0kg/RzEUOM9ngoW2/1QtDkIcY7y51Qo4vrEgIY+nbStEPwj5zkPPS9DRD\nXlSiav8fxHsCbWD48g9FzeOj9EfB+ckRz4OKAAAbdlwq2zKxoIlO0pxiB9axf2EHYE1kL/EK1dE1\n52H4Br4+m4GYG8LU6cWJ74n1P3q7SEuErC8XV6tTyMtyM3LpC9ajzYRcVtvqApAYljCPnr4I9qfp\nIBuO+nO0ahRhVI/ESJK4aDaZrOJvuaFW4UKwAI3QptQAAOPPe5Q9FDiQ/tGG20qr4DQFqTs8Wp4t\nuJ67CJtEXqzCQzo40TuStPFzPK69mWvOZcrJd0XQU/O3KkJ8BrmyvhEczej566MpSD/wZOjAy13q\nDhbKFsbvYpJK7aMsPJBMp4TM2Gv03yJ+WFLzJdaYq+Gz/VwTsAVlmusLpiYsxp1BFty6bPxZO+ck\n49M6oCuGCyWqHgR0H+L7yBtKXm9/0Lltd7WOFevcZsfJ/Xqkbqd4m4jjsumCsccn/8j/fA0ENU8b\nuMYhlzbY/pll8mKCvuPhxEzh09oVxGefG2j4oea19po9Jf6QFv3PbXWv5ZBnl4gCmojqI21l7i+F\nE+eYpYjcG6iXFDBbkK9H0thaJN7lbW0ysl2XhZb+FvvZI/KEJ8rNYxH6+BG9wNvrTg7f8fWBXStd\neOUlySPnOdzeVtHk3zfnzDp+c55nfp2qPzGXXdLgjSyNGH1VlRe4Pv0XT2Yu+y04xH1oESxYZcmY\nZi2Qz0t+Lc4j9CoBheQtxvTh06tQYFLGCeQWpzMXHYl1faHg+dl43dYwPu/nRqmhMhosDwfcauRJ\nSwH1W7hDtkU6eV2i607wbQHiHi4DROzu/jtPAT+MjqTME6dhwJjqFqziP7KT7EMVS55rECT9NnB0\nykpVgq9CHsUdj22o8k5NsQcSj4g/4+p5JxEIJxSoKf4zOe0wmZQyiSeJHu5JE+YVTJFsCGsRDOeU\nTP/5nA+4G2bZ2UFnCabY2esdAL4SkQSJp24RLLnoS3bGmhzzCCIrQ7r79QUGAsFVONFhbb9slEr7\n8R6xUfGrcvJrmDR/00Or351eAgjFXG5tQrL4Gm41l7ObrrH5YLKB0otvmo8c9XYTn6EuVWVOUDa5\nboNm1jreOM6Z/+T4Vvrginhon5d57ZbIX71QSe5V7iX1bLu+67EVGvGwt6cvsRekQQ2vhVOQ2L87\n18r19rqwkpLE4jINmO+r5n+eXvPST687+Xa0sjjSnSlc39dn/xFzonyQ1x/c3IA4g0y/3sb//7z8\nTfgm9OlandDb3vU5ZB++dSafjFb2O6+zQ6jBgoJyNm0d/AmYcP+9loWtQoFDbSzP2OZKs3JmIOR6\n8wXtFoMoQgw2s1FDqZyOMZ8RXMaP9GzzfW+TJgrwD9UbNGWTvoXiDnumYDLmsPM6DQ8yXM49bShN\njzUVuTmg56LmSK/lEEWTSiWqfJs2Xs0flh4OVJSUMwjxlLYbt1OorCo9u+u2rl3NgU8pO4BqsOGm\niDE6pQZYdOVz3wXaDRarntz2BWKPizlfR/ZnLE49EJRc3yYpxRXZzFvz/bF1P8LtFsw4o6WT0A7R\n7bdThvXfgF+iozAqXS/KWPUVL9viTvGtDKnt27UgKMGOh3c5LNCieZ9HdXNKVQ38C/izieu7jpuJ\nw9BpcNRbufSyHT3jsHXDR2qLHvsG7AhUT8+v1iQrbUgc7ckJ/PpKKXqH2Bfy7iGgOCLYtvhRZezg\nTMRgaFwNJqla9ND2DpRzkgQZ8kbP9408owvwxxmUf6xNB9TezBzgNtyOq5MBSDi8OnW9YhyJ1m4w\nqLVRLmIkNoIovKARJJqThRMw3QnvugdbDAT0BRyD50g/5RaNDGBXoFBijCjaUMYsM2WfjQE2j2oL\naUtjvhFReue5Ojyv93inDoz0wjXXvrTl4vHi0ho2Hyb9qZEt59013GobVxHj4zgASz9WoRtFHD0V\nrmkSs4NW23mKCsEKLToYy3OaNPnLh4AkxCdsYJTtKZupVPpum/zEs4wMAUOI9eqi0DTuf0wrihV2\n3jKVxBu7Pq/ahhr3t3CK5EU+NyY9RW68dQ4NIkcB0pTv/MtPTT1nZs6GxyqUDijXG+RuoZxw4UNn\nVYt/QmNfAEVO1VtH1W2t+fUMkc82WWaSSSc7mEeHOx6JKSqvajc0hed3n5Jw3IFjnx4lIFUpihIZ\nfc+Ve7tXJXJSVsB5acVbSuwabnT2nwZ8yoodOYLfrkcCM6irFhdyPb7vmg4FuBfnpY1IP7CH72+r\nIS5HKRXN4qNJLPFeH+ZRRIKQBQGK0UXbpm0exR+zKRfZ17JAlR9q/U1kLYgq1i7SFxP77bErwWmR\nFQE61TPlYaaaf6aErDrgLsus8CQm4gXeBB2uTEsDwr5EcQWGXcC5R8vAnyuziO58MI28YZnR0wfD\ndTIxaR/Rw97//mIpF6OlG4xCm5yslTj8nm9JCZdRXGtySVhtygGPHGqwhldd43i62ADLSkdjr5Rx\nF0B7XRu1uqauYbxzYgZcGNKj8iJP/Y8ZHyhVoqblEA9Bb3RRTLzpyZWJ8dVj2qLRSxIsZXmhwZZD\nTy3bOrjEo09BZjI+jRnNGRk1K2UN83jCrQXFIuCW6G9tZy0jMMMj2sggUBiSk27IZfrGCjGbeosT\n5MN/P7UcVRkK81dEy4+1bDninETQhX66cSIWDmoapGUrttLiZgpjGn40WMdSWnBFNum86udebuHZ\nXX0/YMGh4WzXErcyl5G31OL1hUjALF7eQ1viLc3FmwffiBkZpBh3156hscbyn/Kimlc6O8f4T9zg\nCTTQs1XuOMo5Pp4aTc4Ibycts3EyghTy111//6K56fJTJbuB08rpA99E1bGRAGVH+DjL6Muf4s+b\nSXh89mNdZQibpXTdabddybV6vRQspZxYM06mZYCI0mmHhuRbU4FEwL29ew4hx0PBc5nWjIHc9Rcj\n+KKiWoE0ONlvZg8Tid5gQ453gAj5Feo5QNeFkg4zHxCvXXorzQ3X3A+gNwXs/alh1gUB/ywpREP7\n3rGSLpvnokustXAjdeN5aZmnD3m4nw70vXjMZrqW7YT/xO4YFF6s4eT9c2gTwmYI10mwKRVyDXwA\nPMAB35Yn9qIg2PgiYhOybKkgQWUDZsxn9dxUFBL0LJX7uZLjHDPOmLS7cXaia4J0xMo6dKJdML1X\nT5KuV/ppPGftNVb1Wp7nLm5b9EOobW6uIYqO5WpmBlanmSba8aeOhpHCH2xu8lP6IBCkkePELBRW\ndiQ8ni8ffGqsCjyuSZ8ZXR2B+VD43xe1IXbMYH1cmBQjHHUJY11xz2V7QRmzb+/WJHw2I1qWKwhR\nGlMCNEOoEGyKYqVR3HHTEdIjtPonxp/kKySU6yMAg7qZP0JlLXSGbmjam0L+cpBTxfy7fOzbYx39\n87pvNLdO8K+ABHQlAcKl6+t8iRyr8GJleQlxght/oEwK2cvI0Y5i/0GqMf6iiu6xvHoPnio0Y6ms\nuMsBv2qfY7/7eIx7+MEDZTMx6A2fQcKwmCD+/b32uoa9cHKSMqs5jJ+EinmAMB+c5kwsaOHwGO6G\nkr/2CMwYqzmk4dBsPVD7rTi+xTwJI7FFiJUvmVflWbgRjDPXgfbgn3bvNrEt/w83auMZMVEzFx8u\nEbAYexpH51pIiV/dbRhq8GzFlvrCSCEc2P4wAlkvkyprPT56oLJdGVKtRNLC4EEvHo6Qkme5CAQu\nLjYFQo1TSXenkuC0GNP9n0sgciEvL++iQUz+BU+7N+chERDCkkOzjFFSCyxnAXOMaN32jVLHnipD\nFNTEZN//wH0wEjrAbMvN7Q+EbLe3xkM66dSRm/TEf9GPwgq/eIQQLzp+puCpg6kKaE1iQNkQ5PdE\nUra1uGdujX8uOeU265pxyzuo5D9r02xZvFnmdyxaMvhDLiYgZuKQkEqbdpnBnRi7IberDTj2jjwH\nk8XHXRRQVQnDWBkr7o5+HOAABwwFlFfdEM5lMJ0mxEF6oy4y5VVHYNmPpXLAlXJXQJ4VYujqe0Rj\nfeUTtSsCKNzHV5YlBf/eSu5vykNQ0oVPsvO/OvcoIJZKYEI3c+/fYI11fGP+9Vv/NSlD9jL11Ava\nEwEab7dvvfMwuMX7vksu6qN+7kEto2os/SLdRIT7Q+QBLnG/4nmCYBmEXTrwJVrxo9AgU5gpHatq\n/MOwHbBwkww6fRLo7CLri4KVXWnQ9xX4ak+o8kIvZaHpt0zF9fjRvNvyZv8FdRKU7CZJbJw/JrhT\n/GFyQF6m7CbBj4pVQZ7rmU3KUvYkrFxPrMdY51v74FrLXni3RR+BbNiE/3z5wR7Vjs8Jmb8W8G2o\nSLuJaeazgJWGldv7G+7fy5UiK+v95iEODBjGQocGtJUsDR24V3se0qGv58M7wnXSpK4sOy1u8ou9\n2WlBqFD3rBmqn+shLLBoQveJa/+QDeVC2XJG2toc61/y9177WfIGq9E/kPzGu93kwu4aqOx5xnug\n+l0yuOFp1WlTWhu24ODfDUbqBcz74NDaeSb0AMIgEq2IYnujKgeRPa0uQBK3YIz/m/RkOiUwbXwk\namdDtaEDD3FjQanWhOF3/xZgoFMkX2DA28IZuonj2otjHK8ViSTkXlFMADvyqFpH7RvN4ue7UNDV\nrFrnncCnvzxJ7yY/9zP+H/k3arUTzk1kWSMt3yq4crmZ404xkcc+Dzykzothm6UlrWeGtSj3oMoE\nSX8IjnAhqXYpauD4WK2g2uUsqrASnlNwP4dHGo4ac4DkGadO4oe0LN9Hm516g+k1yOlvhsAI3xXt\n7PQG+DnZ4ebJijkAAADBQZokbEJ//NTNqxOOMY7F5jGnMUjGg82tg7wzn3cuVl82EjpBNJe4xo+F\ntqmWAAADAdCy+NCvjYVFUN91iGE5uCFWevpvyAmXtLWJuEmpp+a1Y3juSjw4c6rn33uyzX/i5HIQ\nCuZ2/7l5NfUw4DvHSL5IXnGEqPD8znvKA8LkiDP7UkWHCi65jRy8/Q0dAPFXtTpoasxy13BzvCwz\n0TJe3HK35KR+fcUriC66KmPEfTZiKGwg6rvihpGG50De2OjZwAAAAHhBnkJ4hP9fF53+8vKH7R6D\nyyI+QqeUK08bMMuo42V6kv2lJx8Ag2Mv0fW+99qHWmMxlyN9xFE+zRP/5A6iAEea3vdU1cX9HpLi\nkf2ZsCI2T0BY+I8sHY+p0hvAeujcGYJ08WIYMVATD67heGb8zRJMSOoAjgwnnRMAAABgAZ5hdEI/\nYWCWGuECLhE3I6FbQF/E7BQt+YqoFIKMmjBA7wnlu1ZrLL8PdAFdsmEAJQD479LhNbmNNT3mJK6h\nQVHpoOEOnMb+LWFTEeeTGjjFAjNZuBjwQhfrw28k0ELBAAAATQGeY2pCPwAAAwEUEv+NNHcl1IZz\nrtdNW+0PxksvyzZrtCUEUb4r+H8HjeGTwsIDqjqLVYAJ08ec7yTybY3jgczhabml0Jdl1AoZjbAg\nAAAAVEGaZUmoQWiZTAhH//3hAAADADO+jfYEchrBr0cTCoYfaaV5us8cNwbTHX+zWg+KwPmu8mSo\n6jb+AD9meH6mVen4WUZm8Srjwy+wlOQRt2K1UwAHdAAADyttb292AAAAbG12aGQAAAAAAAAAAAAA\nAAAAAAPoAAAZAAABAAABAAAAAAAAAAAAAAAAAQAAAAAAAAAAAAAAAAAAAAEAAAAAAAAAAAAAAAAA\nAEAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACAAAOVXRyYWsAAABcdGtoZAAAAAMAAAAA\nAAAAAAAAAAEAAAAAAAAZAAAAAAAAAAAAAAAAAAAAAAAAAQAAAAAAAAAAAAAAAAAAAAEAAAAAAAAA\nAAAAAAAAAEAAAAADYAAAAVgAAAAAACRlZHRzAAAAHGVsc3QAAAAAAAAAAQAAGQAAAAIAAAEAAAAA\nDc1tZGlhAAAAIG1kaGQAAAAAAAAAAAAAAAAAACgAAAEAAFXEAAAAAAAtaGRscgAAAAAAAAAAdmlk\nZQAAAAAAAAAAAAAAAFZpZGVvSGFuZGxlcgAAAA14bWluZgAAABR2bWhkAAAAAQAAAAAAAAAAAAAA\nJGRpbmYAAAAcZHJlZgAAAAAAAAABAAAADHVybCAAAAABAAANOHN0YmwAAAC0c3RzZAAAAAAAAAAB\nAAAApGF2YzEAAAAAAAAAAQAAAAAAAAAAAAAAAAAAAAADYAFYAEgAAABIAAAAAAAAAAEAAAAAAAAA\nAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAY//8AAAAyYXZjQwFkAB//4QAZZ2QAH6zZQNgt+WEA\nAAMAAQAAAwBQDxgxlgEABmjr48siwAAAABx1dWlka2hA8l8kT8W6OaUbzwMj8wAAAAAAAAAYc3R0\ncwAAAAAAAAABAAABAAAAAQAAAAAYc3RzcwAAAAAAAAACAAAAAQAAAPsAAAgIY3R0cwAAAAAAAAD/\nAAAAAQAAAgAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAA\nAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAA\nAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAA\nAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAAB\nAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEA\nAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAA\nAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAF\nAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEA\nAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAA\nAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAA\nAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAA\nAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAAB\nAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEA\nAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAA\nAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAAC\nAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUA\nAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAA\nAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAA\nAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAA\nAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAAB\nAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEA\nAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAA\nAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAA\nAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIA\nAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAA\nAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAA\nAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAA\nAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAAB\nAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEA\nAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAA\nBQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAAB\nAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAA\nAAAAAQAAAQAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAA\nAAABAAAAAAAAAAEAAAEAAAAAAQAABQAAAAABAAACAAAAAAEAAAAAAAAAAQAAAQAAAAABAAAFAAAA\nAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAUAAAAAAQAAAgAAAAABAAAAAAAAAAEAAAEAAAAA\nAgAAAgAAAAABAAAFAAAAAAEAAAIAAAAAAQAAAAAAAAABAAABAAAAAAEAAAIAAAAAHHN0c2MAAAAA\nAAAAAQAAAAEAAAEAAAAAAQAABBRzdHN6AAAAAAAAAAAAAAEAAAAa9AAAAScAAAA9AAAALgAAAB8A\nAABfAAAALAAAACEAAAAeAAAANAAAACUAAAAdAAAAHAAAAC0AAAAlAAAAHQAAABgAAAArAAAAIwAA\nABkAAAAcAAAANAAAACQAAAAaAAAAGQAAAC4AAAAiAAAAGgAAABgAAAAjAAAAIQAAABsAAAAWAAAA\nIAAAACAAAAAWAAAAFgAAAC4AAAAkAAAAGAAAABwAAAAuAAAAJQAAAB0AAAAbAAAALAAAACUAAAAb\nAAAAGQAAACsAAAAkAAAAGwAAABwAAAAuAAAAJgAAABsAAAAdAAAAKwAAACcAAAAdAAAAHgAAADoA\nAAAmAAAAHgAAABwAAAApAAAAJQAAAB0AAAAcAAAALQAAACQAAAAcAAAAGwAAADsAAAAoAAAAHAAA\nAB8AAAA4AAAAKgAAAB4AAAAfAAAAIQAAACYAAAAdAAAAHQAAAC8AAAAmAAAAHQAAAB0AAAAsAAAA\nJwAAAB8AAAAfAAAALgAAACsAAAAeAAAAIAAAADMAAAAqAAAAHgAAABwAAAAiAAAAJgAAAB0AAAAc\nAAAANAAAACgAAAAdAAAAHQAAACEAAAAmAAAAHgAAAB4AAAAtAAAAKgAAACAAAAAhAAAAIAAAACoA\nAAAeAAAAHgAAACwAAAAoAAAAHQAAACAAAAAsAAAAKwAAACAAAAAiAAAAMAAAACgAAAAgAAAAIAAA\nACMAAAAnAAAAHwAAAB8AAAAlAAAAKgAAAB4AAAAfAAAAQwAAAC8AAAAhAAAAJAAAAC4AAAAxAAAA\nIwAAACMAAAArAAAAJwAAABwAAAAcAAAAHwAAACYAAAAcAAAAHAAAAC8AAAAmAAAAHQAAACIAAAA/\nAAAAKgAAAB0AAAAhAAAANQAAACsAAAAgAAAAIgAAACkAAAAoAAAAIQAAAB0AAAAtAAAAJwAAAB0A\nAAAdAAAATgAAADIAAAAgAAAAJQAAADgAAAApAAAAIgAAAB4AAAA5AAAAKwAAACAAAAAeAAAAKgAA\nACgAAAAdAAAAHgAAAC8AAAArAAAAHgAAACAAAABMAAAAKwAAACAAAAAhAAAANwAAACkAAAAgAAAA\nHAAAADIAAAArAAAAIAAAACAAAAApAAAAKAAAAB8AAAAdAAAAOAAAACYAAAAcAAAAHQAAACwAAAAy\nAAAAIQAAACIAAAAyAAAAKQAAAB4AAAAhAAAAMAAAACgAAAAfAAAAHgAAACEAAAAqAAAAHwAAAB4A\nAABBAAAAKQAAAB8AAAAeAAAAUwAAACsAAAAgAAAAIgAAADYAAAAsAAAAIAAAACAAAAAtAAAAMQAA\nACMAAAAjAAAAIAAAFrkAAADFAAAAfAAAAGQAAABRAAAAWAAAABRzdGNvAAAAAAAAAAEAAAAsAAAA\nYnVkdGEAAABabWV0YQAAAAAAAAAhaGRscgAAAAAAAAAAbWRpcmFwcGwAAAAAAAAAAAAAAAAtaWxz\ndAAAACWpdG9vAAAAHWRhdGEAAAABAAAAAExhdmY1Ny44My4xMDA=\n\">\n  Your browser does not support the video tag.\n</video>"}︡{"done":true}
︠f0898f77-5eba-452b-b011-8c93fab93e0ai︠
%md
## Step 3. Summary stats
︡65900a3b-00f5-4db6-83c2-30cfc5d17920︡{"done":true,"md":"## Step 3. Summary stats"}
︠37386c39-d740-40a2-97c9-b3e35aef6b42︠
# maximum obscuration time

max_obsc = dt[sun_moon_sep.argmin()]
print(max_obsc.strftime("%Y-%m-%d %H:%M:%S"))
︡ac066203-d510-4838-92d4-64952d514210︡{"html": "<pre><span style=\"font-family:monospace;\">2024-04-08 14:07:37\n</span></pre>", "done": true}︡
︠223239d3-c6a8-4113-b474-a9acc02a4f13i︠
%md
# look up subtended arcs of sun and moon

- sun: The sun subtends an angle of approximately 0.52° (31 arc-minutes)
- moon: The moon subtends an angle of approximately 0.54° (32 arc-minutes)

https://www.mathopenref.com/subtend.html
︡d219fb06-1ed4-49d1-ae50-27963c20ad63︡{"done":true,"md":"# look up subtended arcs of sun and moon\n\n- sun: The sun subtends an angle of approximately 0.52° (31 arc-minutes)\n- moon: The moon subtends an angle of approximately 0.54° (32 arc-minutes)\n\nhttps://www.mathopenref.com/subtend.html"}
︠823e0955-cf9a-4b5d-8e19-04706e092007︠
# maximum obscuration percent

# area of the lune
# https://rechneronline.de/pi/lune.php

r_sun = 31 * 60 / 2
r_moon = 32 * 60 / 2
s = sun_moon_sep[544].arcsec
ld = lunedelta=0.25*math.sqrt((r_sun+r_moon+s)*(r_moon+s-r_sun)*(s+r_sun-r_moon)*(r_sun+r_moon-s))

lune_area=2*ld + r_sun*r_sun*(math.acos(((r_moon*r_moon)-(r_sun*r_sun)-(s*s))/(2*r_sun*s))) - r_moon*r_moon*(math.acos(((r_moon*r_moon)+(s*s)-(r_sun*r_sun))/(2*r_moon*s)))

# Calculate percentage of sun's disc eclipsed using lune area and sun size
percent_eclipse=(1-(lune_area/(math.pi*r_sun*r_sun)))*100
print(percent_eclipse)
︡3dd0976e-4c92-4c56-9e05-94f2dfe63471︡{"html": "<pre><span style=\"font-family:monospace;\">90.39218524334261\n</span></pre>", "done": true}︡
︠00324b0b-f7cc-45a2-a00b-27f877fb514a︠
# first and last contact times
# look for angular separation around 31.5 arcmin
for ix in range(len(dt)):
    aax = sun_moon_sep[ix].arcmin
    if abs(aax - 31.5) < 0.07:
        dtx = dt[ix]
        print(aax,dtx.strftime("%Y-%m-%d %H:%M:%S"))
︡5909abba-7f3c-48c3-b503-4a4aa4633405︡{"html": "<pre><span style=\"font-family:monospace;\">31.497463254119648 2024-04-08 12:54:39\n31.474618929868615 2024-04-08 15:18:56\n</span></pre>", "done": true}︡
︠3e4a793c-28c7-4314-aab1-e1e3c10ad01bi︠
%md
## Results

US Naval Observatory posted times have been converted from UTC to US/Central.

Source: [Solar Eclipse Computer - Solar Eclipse of 2024 April 08 - Palatine, IL](https://aa.usno.navy.mil/solareclipse?eclipse=12024&state=IL&place=palatine&height=0)


| value | USNO | calculations in this worksheet |
|-----|-----|-----|
| First contact time |12:51:13.9|12:54:39|
| Maximum obscuration time |14:07:14.4|14:07:37|
| Maximum obscuration |92.4%|90.4%|
| Last contact time |15:21:29.0|15:18:56|
︡d314aae4-616b-4214-9a22-ccbf0a5fa0fc︡{"done":true,"md":"## Results\n\nUS Naval Observatory posted times have been converted from UTC to US/Central.\n\nSource: [Solar Eclipse Computer - Solar Eclipse of 2024 April 08 - Palatine, IL](https://aa.usno.navy.mil/solareclipse?eclipse=12024&state=IL&place=palatine&height=0)\n\n\n| value | USNO | calculations in this worksheet |\n|-----|-----|-----|\n| First contact time |12:51:13.9|12:54:39|\n| Maximum obscuration time |14:07:14.4|14:07:37|\n| Maximum obscuration |92.4%|90.4%|\n| Last contact time |15:21:29.0|15:18:56|"}
︠e78fb4ba-5c52-4d1e-af2f-b0564adeb1ac︠









